==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/calendar/api/ICalendarAsync.java <==
package net.bluemind.calendar.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.calendar.api.ICalendar.class)
public interface ICalendarAsync  {

	void getVersion(
	               AsyncHandler<Long> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void containerChangelog(java.lang.Long arg0 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangelog> handler);

	void allIds(java.lang.String filter , java.lang.Long knownContainerVersion , java.lang.Integer limit , java.lang.Integer offset , 
	               AsyncHandler<net.bluemind.core.api.ListResult<java.lang.Long>> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>> handler);

	void multipleDeleteById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<Void> handler);

	void updateById(long id , net.bluemind.calendar.api.VEventSeries arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void deleteById(long id , 
	               AsyncHandler<Void> handler);

	void createById(long id , net.bluemind.calendar.api.VEventSeries arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void update(java.lang.String uid , net.bluemind.calendar.api.VEventSeries event , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void updates(net.bluemind.calendar.api.VEventChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerUpdatesResult> handler);

	void delete(java.lang.String uid , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void search(net.bluemind.calendar.api.VEventQuery query , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void create(java.lang.String uid , net.bluemind.calendar.api.VEventSeries event , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void all(
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void multipleGet(java.util.List<java.lang.String> uids , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void touch(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void list(
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void sync(java.lang.Long since , net.bluemind.calendar.api.VEventChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>> handler);

	void isAutoSyncActivated(
	               AsyncHandler<Boolean> handler);

	void searchPendingCounters(
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void reset(
	               AsyncHandler<net.bluemind.core.task.api.TaskRef> handler);

	void getByIcsUid(java.lang.String uid , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

}

==> net.bluemind.p2.platform-5.4.2696.zip: net/bluemind/calendar/api/ICalendarAsync.java <==
package net.bluemind.calendar.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.calendar.api.ICalendar.class)
public interface ICalendarAsync  {

	void all(
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void create(java.lang.String uid , net.bluemind.calendar.api.VEventSeries event , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void createById(long id , net.bluemind.calendar.api.VEventSeries arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void delete(java.lang.String uid , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void deleteById(long id , 
	               AsyncHandler<Void> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void getByIcsUid(java.lang.String uid , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>> handler);

	void getVersion(
	               AsyncHandler<Long> handler);

	void isAutoSyncActivated(
	               AsyncHandler<Boolean> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void list(
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void multipleDeleteById(java.util.List<java.lang.Long> arg0 , java.lang.Boolean bypassDeletedItems , 
	               AsyncHandler<Void> handler);

	void multipleGet(java.util.List<java.lang.String> uids , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void reset(
	               AsyncHandler<net.bluemind.core.task.api.TaskRef> handler);

	void search(net.bluemind.calendar.api.VEventQuery query , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void searchPendingCounters(
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.calendar.api.VEventSeries>>> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void sortedUids(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void sync(java.lang.Long since , net.bluemind.calendar.api.VEventChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void touch(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void update(java.lang.String uid , net.bluemind.calendar.api.VEventSeries event , java.lang.Boolean sendNotifications , 
	               AsyncHandler<Void> handler);

	void updateById(long id , net.bluemind.calendar.api.VEventSeries arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void updates(net.bluemind.calendar.api.VEventChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerUpdatesResult> handler);

}
